@@ -311,14 +311,17 @@ class WebDriver(webdriver.Remote):
         self.execute_script('mobile: pinchOpen', opts)
         return self
 
-    @property
-    def app_strings(self):
-        """Returns the application strings from the device.
+    def app_strings(self, language=None):
+        """Returns the application strings from the device for the specified
+        language.
 
-        :Usage:
-            strings = driver.app_strings
+        :Args:
+         - language - strings language code
         """
-        return self.execute(Command.GET_APP_STRINGS)['value']
+        data = {}
+        if language != None:
+            data['language'] = language
+        return self.execute(Command.GET_APP_STRINGS, data)['value']
 
     def reset(self):
         """Resets the current application on the device.
@@ -337,7 +340,7 @@ class WebDriver(webdriver.Remote):
         self.execute(Command.HIDE_KEYBOARD, data)
         return self
 
-    def keyevent(self, keycode, metastate=None):
+    def press_keycode(self, keycode, metastate=None):
         """Sends a keycode to the device. Android only. Possible keycodes can be
         found in http://developer.android.com/reference/android/view/KeyEvent.html.
 
@@ -350,7 +353,23 @@ class WebDriver(webdriver.Remote):
         }
         if metastate is not None:
             data['metastate'] = metastate
-        self.execute(Command.KEY_EVENT, data)
+        self.execute(Command.PRESS_KEYCODE, data)
+        return self
+
+    def long_press_keycode(self, keycode, metastate=None):
+        """Sends a long press of keycode to the device. Android only. Possible keycodes can be
+        found in http://developer.android.com/reference/android/view/KeyEvent.html.
+
+        :Args:
+         - keycode - the keycode to be sent to the device
+         - metastate - meta information about the keycode being sent
+        """
+        data = {
+            'keycode': keycode
+        }
+        if metastate != None:
+            data['metastate'] = metastate
+        self.execute(Command.LONG_PRESS_KEYCODE, data)
         return self
 
     @property
@@ -518,9 +537,11 @@ class WebDriver(webdriver.Remote):
         self.command_executor._commands[Command.MULTI_ACTION] = \
             ('POST', '/session/$sessionId/touch/multi/perform')
         self.command_executor._commands[Command.GET_APP_STRINGS] = \
-            ('GET', '/session/$sessionId/appium/app/strings')
-        self.command_executor._commands[Command.KEY_EVENT] = \
-            ('POST', '/session/$sessionId/appium/device/keyevent')
+            ('POST', '/session/$sessionId/appium/app/strings')
+        self.command_executor._commands[Command.PRESS_KEYCODE] = \
+            ('POST', '/session/$sessionId/appium/device/press_keycode')
+        self.command_executor._commands[Command.LONG_PRESS_KEYCODE] = \
+            ('POST', '/session/$sessionId/appium/device/long_press_keycode')
         self.command_executor._commands[Command.GET_CURRENT_ACTIVITY] = \
             ('GET', '/session/$sessionId/appium/device/current_activity')
         self.command_executor._commands[Command.SET_IMMEDIATE_VALUE] = \
